@@ -165,7 +165,11 @@ pStyle defaultLocale node = do
                      lookupAttribute "initialize-with-hyphen" attr
                  , stylePageRangeFormat =
                      case lookupAttribute "page-range-format" attr of
-                       Just "chicago"     -> Just PageRangeChicago
+                       Just "chicago"     -> Just PageRangeChicago15
+                       -- chicago is an alias for chicago-15, but this
+                       -- will change to chicago-16 in v1.1
+                       Just "chicago-15"  -> Just PageRangeChicago15
+                       Just "chicago-16"  -> Just PageRangeChicago16
                        Just "expanded"    -> Just PageRangeExpanded
                        Just "minimal"     -> Just PageRangeMinimal
                        Just "minimal-two" -> Just PageRangeMinimalTwo
@@ -526,9 +530,15 @@ pLayout macroMap node = do
   local (<> attrmap) $ do
     node' <- expandMacros macroMap node
     let layouts = getChildren "layout" node'
-    let formatting = mconcat $ map (getFormatting . getAttributes) layouts
+    -- In case there are multiple layouts (as CSL-M allows), we raise an error
+    let elname = T.unpack $ X.nameLocalName $ X.elementName node
+    layout <- case layouts of
+                [] -> parseFailure $ "No layout element present in " <> elname
+                [l] -> return l
+                (_:_) -> parseFailure $ "Multiple layout elements present in " <> elname
+    let formatting = getFormatting . getAttributes $ layout
     let sorts   = getChildren "sort" node'
-    elements <- mapM pElement (concatMap allChildren layouts)
+    elements <- mapM pElement $ allChildren layout
     let opts = LayoutOptions
                { layoutCollapse =
                    case lookupAttribute "collapse" attr of
